@@ -16,7 +16,6 @@
 
 use std::future::Future;
 use std::iter;
-use std::ops::Bound;
 use std::time::UNIX_EPOCH;
 
 use futures::select_biased;
@@ -43,8 +42,8 @@ fn example_validity() -> (SystemTime, SystemTime) {
         .dangerously_assume_wellsigned()
         .dangerously_into_parts();
     let ret = |tb| match tb {
-        Bound::Included(t) | Bound::Excluded(t) => t,
-        other => panic!("{:?}", other),
+        Some(t) => t,
+        None => panic!("Time range does not have a starting bound"),
     };
     (ret(t), ret(u))
 }
@@ -218,7 +217,7 @@ where
             .and_then(|()| bdm.mgr.lock_only().running.is_empty().then_some(()))
     })
     .await;
-    bdm.set_bridges(&[bridge.clone()]);
+    bdm.set_bridges(std::slice::from_ref(bridge));
 }
 
 fn bad_bridge(i: usize) -> BridgeKey {
@@ -243,7 +242,7 @@ fn success() -> Result<(), anyhow::Error> {
 
         let hold = mock.mstate.lock().await;
 
-        bdm.set_bridges(&[bridge.clone()]);
+        bdm.set_bridges(std::slice::from_ref(&bridge));
         bdm.check_consistency(Some([&bridge]));
 
         drop(hold);
@@ -399,7 +398,7 @@ fn cache() -> Result<(), anyhow::Error> {
 
         eprintln!("----- test that a downloaded descriptor goes into the cache -----");
 
-        bdm.set_bridges(&[bridge.clone()]);
+        bdm.set_bridges(std::slice::from_ref(&bridge));
         stream_drain_until(3, &mut events, || async { in_results(Some(Ok(()))) }).await;
 
         mock.expect_download_calls(1).await;
@@ -482,7 +481,7 @@ fn dormant() -> Result<(), anyhow::Error> {
 
         eprintln!("----- become dormant, but request a bridge -----");
         bdm.set_dormancy(Dormant);
-        bdm.set_bridges(&[bridge.clone()]);
+        bdm.set_bridges(std::slice::from_ref(&bridge));
 
         // Drive all tasks until we are idle
         runtime.progress_until_stalled().await;
@@ -595,7 +594,7 @@ fn process_doc() -> Result<(), anyhow::Error> {
             Err("Descriptor is outside its validity time"),
         );
 
-        // TODO ideally we would test the `ops::Bound::Unbounded` case in process_download's
+        // TODO ideally we would test the unbounded case in process_download's
         // expiry time handling, but that would require making a document with unbounded
         // validity time.  Even if that is possible, I don't think we have code in-tree to
         // make signed test documents.
